@@ -47,7 +47,7 @@ import {
   V1ServiceAccount,
   V1ServiceList,
   Watch,
-  V1CustomResourceDefinition, V1ValidatingWebhookConfiguration,
+  V1CustomResourceDefinition, V1ValidatingWebhookConfiguration, V1MutatingWebhookConfiguration,
 } from '@kubernetes/client-node'
 import { Cluster } from '@kubernetes/client-node/dist/config_types'
 import axios, { AxiosRequestConfig } from 'axios'
@@ -58,8 +58,23 @@ import * as https from 'https'
 import { merge } from 'lodash'
 import * as net from 'net'
 import { Writable } from 'stream'
-import { CHE_CLUSTER_API_GROUP, CHE_CLUSTER_API_VERSION_V1, CHE_CLUSTER_API_VERSION_V2, CHE_CLUSTER_KIND_PLURAL, CHE_TLS_SECRET_NAME, DEFAULT_K8S_POD_ERROR_RECHECK_TIMEOUT, DEFAULT_K8S_POD_WAIT_TIMEOUT } from '../constants'
-import { getClusterClientCommand, getImageNameAndTag, isCheClusterAPIV1, isWebhookAvailabilityError, newError, safeLoadFromYamlFile, sleep } from '../util'
+import {
+  CHE_CLUSTER_API_GROUP,
+  CHE_CLUSTER_API_VERSION_V2,
+  CHE_CLUSTER_KIND_PLURAL,
+  CHE_TLS_SECRET_NAME,
+  DEFAULT_K8S_POD_DOWNLOAD_IMAGE_TIMEOUT,
+  DEFAULT_K8S_POD_ERROR_RECHECK_TIMEOUT,
+  DEFAULT_K8S_POD_WAIT_TIMEOUT,
+} from '../constants'
+import {
+  getClusterClientCommand,
+  isCheClusterAPIV2,
+  isWebhookAvailabilityError,
+  newError,
+  safeLoadFromYamlFile,
+  sleep,
+} from '../util'
 import { ChectlContext } from './context'
 import { V1Certificate } from './types/cert-manager'
 import { CatalogSource, ClusterServiceVersion, ClusterServiceVersionList, InstallPlan, Subscription } from './types/olm'
@@ -77,7 +92,7 @@ export class KubeHelper {
   constructor(flags?: any) {
     this.podWaitTimeout = (flags && flags.k8spodwaittimeout) ? parseInt(flags.k8spodwaittimeout, 10) : DEFAULT_K8S_POD_WAIT_TIMEOUT
     this.podReadyTimeout = (flags && flags.k8spodreadytimeout) ? parseInt(flags.k8spodreadytimeout, 10) : DEFAULT_K8S_POD_WAIT_TIMEOUT
-    this.podDownloadImageTimeout = (flags && flags.k8spoddownloadimagetimeout) ? parseInt(flags.k8spoddownloadimagetimeout, 10) : DEFAULT_K8S_POD_WAIT_TIMEOUT
+    this.podDownloadImageTimeout = (flags && flags.k8spoddownloadimagetimeout) ? parseInt(flags.k8spoddownloadimagetimeout, 10) : DEFAULT_K8S_POD_DOWNLOAD_IMAGE_TIMEOUT
     this.podErrorRecheckTimeout = (flags && flags.spoderrorrechecktimeout) ? parseInt(flags.spoderrorrechecktimeout, 10) : DEFAULT_K8S_POD_ERROR_RECHECK_TIMEOUT
     this.kubeConfig = new KubeConfig()
     this.kubeConfig.loadFromDefault()
@@ -125,27 +140,6 @@ export class KubeHelper {
     }
   }
 
-  async deleteAllServices(namespace: string): Promise<void> {
-    const k8sApi = this.kubeConfig.makeApiClient(CoreV1Api)
-    try {
-      const res = await k8sApi.listNamespacedService(namespace)
-      if (res && res.response && res.response.statusCode === 200) {
-        const serviceList = res.body
-        await serviceList.items.forEach(async service => {
-          try {
-            await k8sApi.deleteNamespacedService(service.metadata!.name!, namespace)
-          } catch (error: any) {
-            if (error.response.statusCode !== 404) {
-              throw error
-            }
-          }
-        })
-      }
-    } catch (e: any) {
-      throw this.wrapK8sClientError(e)
-    }
-  }
-
   async applyResource(yamlPath: string, opts = ''): Promise<void> {
     const command = `kubectl apply -f ${yamlPath} ${opts}`
     await execa(command, { timeout: 60000, shell: true })
@@ -317,7 +311,7 @@ export class KubeHelper {
   async getPodListByLabel(namespace: string, labelSelector: string): Promise<V1Pod[]> {
     const k8sCoreApi = this.kubeConfig.makeApiClient(CoreV1Api)
     try {
-      const {body: podList} = await k8sCoreApi.listNamespacedPod(namespace, undefined, undefined, undefined, undefined, labelSelector)
+      const { body: podList } = await k8sCoreApi.listNamespacedPod(namespace, undefined, undefined, undefined, undefined, labelSelector)
 
       return podList.items
     } catch (e: any) {
@@ -377,6 +371,9 @@ export class KubeHelper {
   async replaceValidatingWebhookConfiguration(name: string, webhook: V1ValidatingWebhookConfiguration): Promise<void> {
     const k8sAdmissionApi = this.kubeConfig.makeApiClient(AdmissionregistrationV1Api)
     try {
+      const response = await k8sAdmissionApi.readValidatingWebhookConfiguration(name)
+      webhook.metadata!.resourceVersion = (response.body as any).metadata.resourceVersion
+
       await k8sAdmissionApi.replaceValidatingWebhookConfiguration(name, webhook)
     } catch (e: any) {
       throw this.wrapK8sClientError(e)
@@ -403,6 +400,41 @@ export class KubeHelper {
     }
   }
 
+  async isMutatingWebhookConfigurationExists(name: string): Promise<boolean> {
+    const k8sAdmissionApi = this.kubeConfig.makeApiClient(AdmissionregistrationV1Api)
+    try {
+      await k8sAdmissionApi.readMutatingWebhookConfiguration(name)
+      return true
+    } catch (e: any) {
+      if (e.response && e.response.statusCode === 404) {
+        return false
+      }
+
+      throw this.wrapK8sClientError(e)
+    }
+  }
+
+  async replaceVMutatingWebhookConfiguration(name: string, webhook: V1MutatingWebhookConfiguration): Promise<void> {
+    const k8sAdmissionApi = this.kubeConfig.makeApiClient(AdmissionregistrationV1Api)
+    try {
+      const response = await k8sAdmissionApi.readMutatingWebhookConfiguration(name)
+      webhook.metadata!.resourceVersion = (response.body as any).metadata.resourceVersion
+
+      await k8sAdmissionApi.replaceMutatingWebhookConfiguration(name, webhook)
+    } catch (e: any) {
+      throw this.wrapK8sClientError(e)
+    }
+  }
+
+  async createMutatingWebhookConfiguration(webhook: V1MutatingWebhookConfiguration): Promise<void> {
+    const k8sAdmissionApi = this.kubeConfig.makeApiClient(AdmissionregistrationV1Api)
+    try {
+      await k8sAdmissionApi.createMutatingWebhookConfiguration(webhook)
+    } catch (e: any) {
+      throw this.wrapK8sClientError(e)
+    }
+  }
+
   async deleteMutatingWebhookConfiguration(name: string): Promise<void> {
     const k8sAdmissionApi = this.kubeConfig.makeApiClient(AdmissionregistrationV1Api)
     try {
@@ -442,6 +474,7 @@ export class KubeHelper {
     const k8sRbacAuthApi = this.kubeConfig.makeApiClient(RbacAuthorizationV1Api)
     try {
       delete yamlRoleBinding.metadata?.namespace
+      yamlRoleBinding.subjects![0].namespace = namespace
       await k8sRbacAuthApi.createNamespacedRoleBinding(namespace, yamlRoleBinding)
     } catch (e: any) {
       throw this.wrapK8sClientError(e)
@@ -452,6 +485,7 @@ export class KubeHelper {
     const k8sRbacAuthApi = this.kubeConfig.makeApiClient(RbacAuthorizationV1Api)
     try {
       delete yamlRoleBinding.metadata?.namespace
+      yamlRoleBinding.subjects![0].namespace = namespace
       await k8sRbacAuthApi.replaceNamespacedRoleBinding(yamlRoleBinding.metadata!.name!, namespace, yamlRoleBinding)
     } catch (e: any) {
       throw this.wrapK8sClientError(e)
@@ -515,10 +549,10 @@ export class KubeHelper {
     }
   }
 
-  async listConfigMaps(namespace: string): Promise<V1ConfigMap[]> {
+  async listConfigMaps(namespace: string, labelSelector: string | undefined): Promise<V1ConfigMap[]> {
     const k8sCoreApi = this.kubeConfig.makeApiClient(CoreV1Api)
     try {
-      const { body } = await k8sCoreApi.listNamespacedConfigMap(namespace)
+      const { body } = await k8sCoreApi.listNamespacedConfigMap(namespace, undefined, undefined, undefined, undefined, labelSelector)
       return body.items
     } catch (e: any) {
       throw this.wrapK8sClientError(e)
@@ -606,7 +640,7 @@ export class KubeHelper {
     }
   }
 
-  async patchCustomResource(name: string, namespace: string, patch: any, resourceAPIGroup: string, resourceAPIVersion: string, resourcePlural: string): Promise<any | undefined> {
+  async patchNamespacedCustomResource(name: string, namespace: string, patch: any, resourceAPIGroup: string, resourceAPIVersion: string, resourcePlural: string): Promise<any | undefined> {
     const k8sCoreApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
 
     // It is required to patch content-type, otherwise request will be rejected with 415 (Unsupported media type) error.
@@ -626,6 +660,78 @@ export class KubeHelper {
     }
   }
 
+  async patchClusterCustomObject(name: string, patch: any, resourceAPIGroup: string, resourceAPIVersion: string, resourcePlural: string): Promise<any | undefined> {
+    const k8sCoreApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
+
+    // It is required to patch content-type, otherwise request will be rejected with 415 (Unsupported media type) error.
+    const requestOptions = {
+      headers: {
+        'content-type': 'application/merge-patch+json',
+      },
+    }
+
+    try {
+      const res = await k8sCoreApi.patchClusterCustomObject(resourceAPIGroup, resourceAPIVersion, resourcePlural, name, patch, undefined, undefined, undefined, requestOptions)
+      if (res && res.body) {
+        return res.body
+      }
+    } catch (e: any) {
+      throw this.wrapK8sClientError(e)
+    }
+  }
+
+  async getClusterCustomObject(group: string, version: string, plural: string, name: any): Promise<any> {
+    const k8sCoreApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
+    try {
+      const { body } = await k8sCoreApi.getClusterCustomObject(group, version, plural, name)
+      return body
+    } catch (e: any) {
+      if (e.response.statusCode !== 404) {
+        throw this.wrapK8sClientError(e)
+      }
+    }
+  }
+
+  async createClusterCustomObject(group: string, version: string, plural: string, body: any): Promise<void> {
+    const k8sCoreApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
+    try {
+      await k8sCoreApi.createClusterCustomObject(group, version, plural, body)
+    } catch (e: any) {
+      throw this.wrapK8sClientError(e)
+    }
+  }
+
+  async deleteClusterCustomObject(group: string, version: string, plural: string, name: string): Promise<void> {
+    const k8sCoreApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
+    try {
+      await k8sCoreApi.deleteClusterCustomObject(group, version, plural, name)
+      cli.debug(`Deleted ${plural}.${version}.${group} ${name} resource`)
+    } catch (e: any) {
+      if (e.response.statusCode !== 404) {
+        throw this.wrapK8sClientError(e)
+      }
+    }
+  }
+
+  async patchDevWorkspaceOperatorConfig(name: string, namespace: string, patch: any): Promise<any> {
+    try {
+      const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
+      const { body } = await customObjectsApi.patchNamespacedCustomObject('controller.devfile.io', 'v1alpha1', namespace, 'devworkspaceoperatorconfigs', name, patch, undefined, undefined, undefined, { headers: { 'Content-Type': 'application/merge-patch+json' } })
+      return body
+    } catch (e: any) {
+      throw this.wrapK8sClientError(e)
+    }
+  }
+
+  async createDevWorkspaceOperatorConfig(devWorkspaceOperatorConfig: any, namespace: string): Promise<void> {
+    const k8sCoreApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
+    try {
+      await k8sCoreApi.createNamespacedCustomObject('controller.devfile.io', 'v1alpha1', namespace, 'devworkspaceoperatorconfigs', devWorkspaceOperatorConfig)
+    } catch (e: any) {
+      throw this.wrapK8sClientError(e)
+    }
+  }
+
   /**
    * Returns pod waiting state.
    */
@@ -905,6 +1011,18 @@ export class KubeHelper {
     }
   }
 
+  async deletePod(name: string, namespace: string): Promise<void> {
+    const k8sApi = this.kubeConfig.makeApiClient(CoreV1Api)
+    try {
+      await k8sApi.deleteNamespacedPod(name, namespace)
+    } catch (e: any) {
+      if (e.response && e.response.statusCode === 404) {
+        return
+      }
+      throw this.wrapK8sClientError(e)
+    }
+  }
+
   async replaceDeployment(yamlDeployment: V1Deployment): Promise<void> {
     // updating restartedAt to make sure that rollout will be restarted
     let annotations = yamlDeployment.spec!.template!.metadata!.annotations
@@ -942,15 +1060,6 @@ export class KubeHelper {
     }
   }
 
-  async deleteAllDeployments(namespace: string): Promise<void> {
-    const k8sAppsApi = this.kubeConfig.makeApiClient(AppsV1Api)
-    try {
-      await k8sAppsApi.deleteCollectionNamespacedDeployment(namespace)
-    } catch (e: any) {
-      throw this.wrapK8sClientError(e)
-    }
-  }
-
   async getDeployment(name: string, namespace: string): Promise<V1Deployment | undefined> {
     const k8sAppsApi = this.kubeConfig.makeApiClient(AppsV1Api)
     try {
@@ -990,16 +1099,7 @@ export class KubeHelper {
     }
   }
 
-  async deleteAllIngresses(namespace: string): Promise<void> {
-    const networkingV1Api = this.kubeConfig.makeApiClient(NetworkingV1Api)
-    try {
-      await networkingV1Api.deleteCollectionNamespacedIngress(namespace)
-    } catch (e: any) {
-      throw this.wrapK8sClientError(e)
-    }
-  }
-
-  async createCrdFromFile(crd: V1CustomResourceDefinition): Promise<void> {
+  async createCrd(crd: V1CustomResourceDefinition): Promise<void> {
     const k8sApi = this.kubeConfig.makeApiClient(ApiextensionsV1Api)
     try {
       await k8sApi.createCustomResourceDefinition(crd)
@@ -1008,7 +1108,7 @@ export class KubeHelper {
     }
   }
 
-  async replaceCrdFromFile(crd: V1CustomResourceDefinition): Promise<void> {
+  async replaceCustomResourceDefinition(crd: V1CustomResourceDefinition): Promise<void> {
     const k8sApi = this.kubeConfig.makeApiClient(ApiextensionsV1Api)
     try {
       const response = await k8sApi.readCustomResourceDefinition(crd.metadata!.name!)
@@ -1020,7 +1120,7 @@ export class KubeHelper {
     }
   }
 
-  async getCrd(name: string): Promise<any | undefined> {
+  async getCustomResourceDefinition(name: string): Promise<any | undefined> {
     const k8sApi = this.kubeConfig.makeApiClient(ApiextensionsV1Api)
     try {
       const { body } = await k8sApi.readCustomResourceDefinition(name)
@@ -1029,96 +1129,54 @@ export class KubeHelper {
       if (e.response && e.response.statusCode === 404) {
         return
       }
-
       throw this.wrapK8sClientError(e)
     }
   }
 
   async createCheCluster(cheClusterCR: any, flags: any, ctx: any, useDefaultCR: boolean): Promise<any> {
-    const isCheClusterApiV1 = isCheClusterAPIV1(cheClusterCR)
-    const cheClusterApiVersion = isCheClusterApiV1 ? CHE_CLUSTER_API_VERSION_V1 : CHE_CLUSTER_API_VERSION_V2
+    if (!isCheClusterAPIV2(cheClusterCR)) {
+      throw new Error(`CheCluster apiVersion must be '${CHE_CLUSTER_API_GROUP}/${CHE_CLUSTER_API_VERSION_V2}'`)
+    }
 
     const cheNamespace = flags.chenamespace
     if (useDefaultCR) {
-      if (isCheClusterApiV1) {
-        if (flags.cheimage) {
-          const [image, tag] = getImageNameAndTag(flags.cheimage)
-          cheClusterCR.spec.server.cheImage = image
-          cheClusterCR.spec.server.cheImageTag = tag
-        }
+      if (flags.cheimage) {
+        merge(cheClusterCR, { spec: { components: { cheServer: { deployment: { containers: [{ image: flags.cheimage }] } } } } })
+      }
 
-        cheClusterCR.spec.server.cheDebug = flags.debug ? flags.debug.toString() : 'false'
+      merge(cheClusterCR, { spec: { components: { cheServer: { debug: flags.debug } } } })
 
-        if (!cheClusterCR.spec.k8s?.tlsSecretName) {
-          merge(cheClusterCR, { spec: { k8s: { tlsSecretName: CHE_TLS_SECRET_NAME } } })
+      if (!ctx[ChectlContext.IS_OPENSHIFT]) {
+        if (!cheClusterCR.spec.networking?.tlsSecretName) {
+          merge(cheClusterCR, { spec: { networking: { tlsSecretName: CHE_TLS_SECRET_NAME } } })
         }
 
         if (flags.domain) {
-          merge(cheClusterCR, { spec: { k8s: { ingressDomain: flags.domain } } })
+          merge(cheClusterCR, { spec: { networking: { domain: flags.domain } } })
         }
+      }
 
-        const pluginRegistryUrl = flags['plugin-registry-url']
-        if (pluginRegistryUrl) {
-          cheClusterCR.spec.server.pluginRegistryUrl = pluginRegistryUrl
-          cheClusterCR.spec.server.externalPluginRegistry = true
-        }
+      const pluginRegistryUrl = flags['plugin-registry-url']
+      if (pluginRegistryUrl) {
+        merge(cheClusterCR, { spec: { components: { pluginRegistry: { disableInternalRegistry: true, externalPluginRegistries: [{ url: pluginRegistryUrl }] } } } })
+      }
 
-        const devfileRegistryUrl = flags['devfile-registry-url']
-        if (devfileRegistryUrl) {
-          cheClusterCR.spec.server.devfileRegistryUrl = devfileRegistryUrl
-          cheClusterCR.spec.server.externalDevfileRegistry = true
-        }
+      const devfileRegistryUrl = flags['devfile-registry-url']
+      if (devfileRegistryUrl) {
+        merge(cheClusterCR, { spec: { components: { devfileRegistry: { disableInternalRegistry: true, externalDevfileRegistries: [{ url: devfileRegistryUrl }] } } } })
+      }
 
-        if (flags['postgres-pvc-storage-class-name']) {
-          cheClusterCR.spec.storage.postgresPVCStorageClassName = flags['postgres-pvc-storage-class-name']
-        }
+      if (flags['postgres-pvc-storage-class-name']) {
+        merge(cheClusterCR, { spec: { components: { database: { pvc: { storageClass: flags['postgres-pvc-storage-class-name'] } } } } })
+      }
 
-        if (flags['workspace-pvc-storage-class-name']) {
-          cheClusterCR.spec.storage.workspacePVCStorageClassName = flags['workspace-pvc-storage-class-name']
-        }
-      } else {
-        if (flags.cheimage) {
-          merge(cheClusterCR, { spec: { components: { cheServer: { deployment: { containers: [{ image: flags.cheimage }] } } } } })
-        }
-
-        merge(cheClusterCR, { spec: { components: { cheServer: { debug: flags.debug } } } })
-
-        if (!ctx[ChectlContext.IS_OPENSHIFT]) {
-          if (!cheClusterCR.spec.networking?.tlsSecretName) {
-            merge(cheClusterCR, { spec: { networking: { tlsSecretName: CHE_TLS_SECRET_NAME } }  })
-          }
-
-          if (flags.domain) {
-            merge(cheClusterCR, { spec: { networking: { domain: flags.domain } }  })
-          }
-        }
-
-        const pluginRegistryUrl = flags['plugin-registry-url']
-        if (pluginRegistryUrl) {
-          merge(cheClusterCR, { spec: { components: { pluginRegistry: { disableInternalRegistry: true, externalPluginRegistries: [{ url: pluginRegistryUrl }]} } } })
-        }
-
-        const devfileRegistryUrl = flags['devfile-registry-url']
-        if (devfileRegistryUrl) {
-          merge(cheClusterCR, { spec: { components: { devfileRegistry: { disableInternalRegistry: true, externalDevfileRegistries: [{ url: devfileRegistryUrl }]} } } })
-        }
-
-        if (flags['postgres-pvc-storage-class-name']) {
-          merge(cheClusterCR, { spec: { components: { database: { pvc: { storageClass: flags['postgres-pvc-storage-class-name'] } } } } })
-        }
-
-        if (flags['workspace-pvc-storage-class-name']) {
-          merge(cheClusterCR, { spec: {workspaces: { storage: { pvc: { storageClass: flags['workspace-pvc-storage-class-name'] } } } } })
-        }
+      if (flags['workspace-pvc-storage-class-name']) {
+        merge(cheClusterCR, { spec: { workspaces: { storage: { pvc: { storageClass: flags['workspace-pvc-storage-class-name'] } } } } })
       }
     }
 
     if (ctx.namespaceEditorClusterRoleName) {
-      if (isCheClusterApiV1) {
-        cheClusterCR.spec.server.cheClusterRoles = ctx.namespaceEditorClusterRoleName
-      } else {
-        merge(cheClusterCR, { spec: {components: { cheServer: { clusterRoles: (ctx.namespaceEditorClusterRoleName as string).split(',')} } } })
-      }
+      merge(cheClusterCR, { spec: { components: { cheServer: { clusterRoles: (ctx.namespaceEditorClusterRoleName as string).split(',') } } } })
     }
 
     // override default values with patch
@@ -1126,12 +1184,11 @@ export class KubeHelper {
       merge(cheClusterCR, ctx[ChectlContext.CR_PATCH])
     }
 
-    // TODO remove in the future version
     for (let i = 0; i < 30; i++) {
       const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
       try {
         delete cheClusterCR.metadata?.namespace
-        const {body} = await customObjectsApi.createNamespacedCustomObject(CHE_CLUSTER_API_GROUP, cheClusterApiVersion, cheNamespace, CHE_CLUSTER_KIND_PLURAL, cheClusterCR)
+        const { body } = await customObjectsApi.createNamespacedCustomObject(CHE_CLUSTER_API_GROUP, CHE_CLUSTER_API_VERSION_V2, cheNamespace, CHE_CLUSTER_KIND_PLURAL, cheClusterCR)
         return body
       } catch (e: any) {
         const wrappedError = this.wrapK8sClientError(e)
@@ -1145,30 +1202,27 @@ export class KubeHelper {
   }
 
   async patchCheCluster(name: string, namespace: string, patch: any): Promise<any> {
-    if (!patch.apiVersion) {
-      throw new Error('Patch must contain CheCluster api version.')
+    if (!isCheClusterAPIV2(patch)) {
+      throw new Error(`CheCluster apiVersion must be '${CHE_CLUSTER_API_GROUP}/${CHE_CLUSTER_API_VERSION_V2}'`)
     }
 
-    const isCheClusterApiV1 = isCheClusterAPIV1(patch)
-    const cheClusterApiVersion = isCheClusterApiV1 ? CHE_CLUSTER_API_VERSION_V1 : CHE_CLUSTER_API_VERSION_V2
-
     try {
       const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
-      const { body } = await customObjectsApi.patchNamespacedCustomObject(CHE_CLUSTER_API_GROUP, cheClusterApiVersion, namespace, CHE_CLUSTER_KIND_PLURAL, name, patch, undefined, undefined, undefined, { headers: { 'Content-Type': 'application/merge-patch+json' } })
+      const { body } = await customObjectsApi.patchNamespacedCustomObject(CHE_CLUSTER_API_GROUP, CHE_CLUSTER_API_VERSION_V2, namespace, CHE_CLUSTER_KIND_PLURAL, name, patch, undefined, undefined, undefined, { headers: { 'Content-Type': 'application/merge-patch+json' } })
       return body
     } catch (e: any) {
       throw this.wrapK8sClientError(e)
     }
   }
 
-  /**
-   * Returns `checlusters.org.eclipse.che' in the given namespace.
-   */
-  async getCheClusterV1(cheNamespace: string): Promise<any | undefined> {
-    // TODO remove in the future version
+  async getCheClusterV2(cheNamespace: string): Promise<any | undefined> {
+    return this.getCheCluster(CHE_CLUSTER_API_VERSION_V2, cheNamespace)
+  }
+
+  private async getCheCluster(cheClusterVersion: string, cheNamespace: string): Promise<any | undefined> {
     for (let i = 0; i < 30; i++) {
       try {
-        return await this.findCustomResource(cheNamespace, CHE_CLUSTER_API_GROUP, CHE_CLUSTER_API_VERSION_V1, CHE_CLUSTER_KIND_PLURAL)
+        return await this.findCustomResource(cheNamespace, CHE_CLUSTER_API_GROUP, cheClusterVersion, CHE_CLUSTER_KIND_PLURAL)
       } catch (e: any) {
         if (isWebhookAvailabilityError(e)) {
           await sleep(5 * 1000)
@@ -1180,10 +1234,9 @@ export class KubeHelper {
   }
 
   async getAllCheClusters(): Promise<any[]> {
-    // TODO remove in the future version
     for (let i = 0; i < 30; i++) {
       try {
-        return await this.listCustomResources(CHE_CLUSTER_API_GROUP, CHE_CLUSTER_API_VERSION_V1, CHE_CLUSTER_KIND_PLURAL)
+        return await this.listClusterCustomObject(CHE_CLUSTER_API_GROUP, CHE_CLUSTER_API_VERSION_V2, CHE_CLUSTER_KIND_PLURAL)
       } catch (e: any) {
         if (isWebhookAvailabilityError(e)) {
           await sleep(5 * 1000)
@@ -1196,10 +1249,27 @@ export class KubeHelper {
     return []
   }
 
-  async deleteAllCustomResources(apiGroup: string, version: string, plural: string): Promise<void> {
+  async deleteAllCustomResourcesAndCrd(crdName: string, apiGroup: string, version: string, plural: string): Promise<void> {
     const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
 
-    let resources = await this.listCustomResources(apiGroup, version, plural)
+    const crd = await this.getCustomResourceDefinition(crdName)
+    if (!crd) {
+      return
+    }
+
+    // 1. Disable conversion webhook
+    await this.patchClusterCustomObject(crdName, {spec: {conversion: null}}, 'apiextensions.k8s.io', 'v1', 'customresourcedefinitions')
+
+    // 2. Patch CRD to unblock potential invalid resource
+    for (let i = 0; i < crd.spec.versions.length; i++) {
+      if (crd.spec.versions[i].schema?.openAPIV3Schema?.properties?.spec) {
+        crd.spec.versions[i].schema.openAPIV3Schema.properties.spec = {type: 'object', properties: {}}
+      }
+    }
+    await this.replaceCustomResourceDefinition(crd)
+
+    // 3. Delete resources
+    let resources = await this.listClusterCustomObject(apiGroup, version, plural)
     for (const resource of resources) {
       const name = resource.metadata.name
       const namespace = resource.metadata.namespace
@@ -1210,34 +1280,39 @@ export class KubeHelper {
       }
     }
 
+    // wait and check
     for (let i = 0; i < 12; i++) {
-      await cli.wait(5 * 1000)
-      const resources = await this.listCustomResources(apiGroup, version, plural)
+      await cli.wait(5000)
+      const resources = await this.listClusterCustomObject(apiGroup, version, plural)
       if (resources.length === 0) {
-        return
+        break
       }
     }
 
-    // remove finalizers
+    // 4. Remove finalizers
+    resources = await this.listClusterCustomObject(apiGroup, version, plural)
     for (const resource of resources) {
       const name = resource.metadata.name
       const namespace = resource.metadata.namespace
       try {
-        await this.patchCustomResource(name, namespace, { metadata: { finalizers: null } }, apiGroup, version, plural)
+        await this.patchNamespacedCustomResource(name, namespace, { metadata: { finalizers: null } }, apiGroup, version, plural)
       } catch (error) {
-        if (!await this.getCustomResource(name, namespace, apiGroup, version, plural)) {
-          continue // successfully removed
+        if (error.cause?.body?.reason === 'NotFound') {
+          continue
         }
         throw error
       }
     }
 
-    // wait for some time and check again
+    // wait and delete CRD
     await cli.wait(5000)
+    await this.deleteCustomResourceDefinition(crdName)
 
-    resources = await this.listCustomResources(apiGroup, version, plural)
+    // wait and check
+    await cli.wait(5000)
+    resources = await this.listClusterCustomObject(apiGroup, version, plural)
     if (resources.length !== 0) {
-      throw new Error(`Failed to remove Custom Resource ${apiGroup}/${version}, ${resources.length} left.`)
+      throw new Error(`Failed to remove Custom Resources: ${plural}${apiGroup}, ${resources.length} resource(s) left.`)
     }
   }
 
@@ -1286,7 +1361,7 @@ export class KubeHelper {
   /**
    * Returns all custom resources
    */
-  async listCustomResources(resourceAPIGroup: string, resourceAPIVersion: string, resourcePlural: string): Promise<any[]> {
+  async listClusterCustomObject(resourceAPIGroup: string, resourceAPIVersion: string, resourcePlural: string): Promise<any[]> {
     const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
     try {
       const { body } = await customObjectsApi.listClusterCustomObject(resourceAPIGroup, resourceAPIVersion, resourcePlural)
@@ -1300,10 +1375,6 @@ export class KubeHelper {
     }
   }
 
-  async deleteAllCheClusters(namespace: string): Promise<void> {
-    return this.deleteCustomResource(namespace, CHE_CLUSTER_API_GROUP, CHE_CLUSTER_API_VERSION_V1, CHE_CLUSTER_KIND_PLURAL)
-  }
-
   /**
    * Deletes custom resources in the given namespace.
    */
@@ -1356,46 +1427,13 @@ export class KubeHelper {
   async listCatalogSources(namespace: string, labelSelector: string): Promise<any[]> {
     const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
     try {
-      const {body} = await customObjectsApi.listNamespacedCustomObject('operators.coreos.com', 'v1alpha1', namespace, 'catalogsources', undefined, undefined, undefined, labelSelector)
+      const { body } = await customObjectsApi.listNamespacedCustomObject('operators.coreos.com', 'v1alpha1', namespace, 'catalogsources', undefined, undefined, undefined, labelSelector)
       return (body as any).items
     } catch (e: any) {
       throw this.wrapK8sClientError(e)
     }
   }
 
-  async listOAuthClientBySelector(selector: string): Promise<any[]> {
-    const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
-    try {
-      const {body} = await customObjectsApi.listClusterCustomObject('oauth.openshift.io', 'v1', 'oauthclients', undefined, undefined, undefined, selector)
-      return (body as any).items
-    } catch (e: any) {
-      throw this.wrapK8sClientError(e)
-    }
-  }
-
-  async deleteOAuthClient(name: string): Promise<void> {
-    const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
-    try {
-      await customObjectsApi.deleteClusterCustomObject('oauth.openshift.io', 'v1', 'oauthclients', name)
-    } catch (e: any) {
-      if (e.response && e.response.statusCode === 404) {
-        return
-      }
-      throw this.wrapK8sClientError(e)
-    }
-  }
-
-  async deleteConsoleLink(name: string): Promise<void> {
-    const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
-    try {
-      await customObjectsApi.deleteClusterCustomObject('console.openshift.io', 'v1', 'consolelinks', name)
-    } catch (e: any) {
-      if (e.response.statusCode !== 404) {
-        throw this.wrapK8sClientError(e)
-      }
-    }
-  }
-
   readCatalogSourceFromFile(filePath: string): CatalogSource {
     const catalogSource = this.safeLoadFromYamlFile(filePath) as CatalogSource
     if (!catalogSource.metadata || !catalogSource.metadata.name) {
@@ -1688,7 +1726,7 @@ export class KubeHelper {
     }
   }
 
-  async deleteCrd(name: string): Promise<void> {
+  async deleteCustomResourceDefinition(name: string): Promise<void> {
     const k8sApi = this.kubeConfig.makeApiClient(ApiextensionsV1Api)
     try {
       await k8sApi.deleteCustomResourceDefinition(name)
