@@ -14,21 +14,29 @@ import { Command, flags } from '@oclif/command'
 import { boolean } from '@oclif/command/lib/flags'
 import { cli } from 'cli-ux'
 import * as Listrq from 'listr'
-import { OLMDevWorkspaceTasks } from '../../tasks/component-installers/devworkspace/olm-installer'
+import { OLMDevWorkspaceTasks } from '../../tasks/components/devworkspace-olm-installer'
 import { ChectlContext } from '../../api/context'
 import { KubeHelper } from '../../api/kube'
 import { assumeYes, batch, cheNamespace, CHE_TELEMETRY, listrRenderer, skipKubeHealthzCheck } from '../../common-flags'
 import {
   DEFAULT_ANALYTIC_HOOK_NAME,
-  DEFAULT_CHE_NAMESPACE, OPENSHIFT_OPERATORS_NAMESPACE, WORKSPACE_CONTROLLER_NAMESPACE,
+  DEFAULT_CHE_NAMESPACE, DSC_PROJECT_NAME, OPENSHIFT_OPERATORS_NAMESPACE, WORKSPACE_CONTROLLER_NAMESPACE,
 } from '../../constants'
 import { CheTasks } from '../../tasks/che'
-import { DevWorkspaceTasks } from '../../tasks/component-installers/devworkspace/operator-installer'
-import { OLMTasks } from '../../tasks/installers/olm'
-import { OperatorTasks } from '../../tasks/installers/operator'
+import { DevWorkspaceTasks } from '../../tasks/components/devworkspace-operator-installer'
+import { CheOLMInstaller } from '../../tasks/installers/olm/che-olm'
+import { OperatorInstaller } from '../../tasks/installers/operator'
 import { ApiTasks } from '../../tasks/platforms/api'
-import { findWorkingNamespace, getCommandSuccessMessage, notifyCommandCompletedSuccessfully, wrapCommandError } from '../../util'
+import {
+  findWorkingNamespace,
+  getCommandSuccessMessage,
+  getProjectName,
+  notifyCommandCompletedSuccessfully,
+  wrapCommandError,
+} from '../../util'
 import Listr = require('listr')
+import { DevSpacesOLMInstaller } from '../../tasks/installers/olm/ds-olm'
+import { Installer } from '../../api/types/installer'
 
 export default class Delete extends Command {
   static description = 'delete any Red Hat OpenShift Dev Spaces related resource'
@@ -77,30 +85,29 @@ export default class Delete extends Command {
       title: 'Uninstall Dev Workspace Operator',
       task: async (_ctx: any, _task: any) => {
         if (flags['delete-all']) {
-          const olmDevWorkspaceTasks = new OLMDevWorkspaceTasks(flags)
-          const devWorkspaceTasks = new DevWorkspaceTasks(flags)
-
           const tasks = new Listrq([], ctx.listrOptions)
-          tasks.add({
-            title: 'Delete Custom Resources',
-            task: () => new Listr(devWorkspaceTasks.getDeleteCRsTasks()),
-          })
-
-          let devWorkspaceNamespace = WORKSPACE_CONTROLLER_NAMESPACE
-          if (await olmDevWorkspaceTasks.isDevWorkspaceOperatorInstalledViaOLM()) {
-            devWorkspaceNamespace = OPENSHIFT_OPERATORS_NAMESPACE
-
-            tasks.add({
-              title: 'Delete OLM resources',
-              task: () => new Listr(olmDevWorkspaceTasks.getDeleteTasks()),
-            })
-          }
 
           tasks.add({
             title: 'Delete operator resources',
-            task: () => new Listr(devWorkspaceTasks.getDeleteTasks(devWorkspaceNamespace)),
+            task: () => {
+              const devWorkspaceTasks = new DevWorkspaceTasks(flags)
+              if (ctx[ChectlContext.IS_OPENSHIFT]) {
+                return new Listr(devWorkspaceTasks.getDeleteTasks(OPENSHIFT_OPERATORS_NAMESPACE))
+              } else {
+                return new Listr(devWorkspaceTasks.getDeleteTasks(WORKSPACE_CONTROLLER_NAMESPACE))
+              }
+            },
           })
 
+          if (ctx[ChectlContext.IS_OPENSHIFT]) {
+            tasks.add({
+              title: 'Delete OLM resources',
+              task: () => {
+                const olmDevWorkspaceTasks = new OLMDevWorkspaceTasks(flags)
+                return new Listr(olmDevWorkspaceTasks.getDeleteTasks())
+              },
+            })
+          }
           return tasks
         }
       },
@@ -108,30 +115,43 @@ export default class Delete extends Command {
 
     tasks.add({
       title: 'Uninstall Red Hat OpenShift Dev Spaces Operator',
-      task: async (_ctx: any, _task: any) => {
-        const operatorTasks = new OperatorTasks(flags)
-        const olmTasks = new OLMTasks(flags)
-        const cheTasks = new CheTasks(flags)
-
+      task: async (ctx: any, _task: any) => {
         const tasks = new Listrq([], ctx.listrOptions)
-        tasks.add({
-          title: 'Delete Custom Resources',
-          task: () => new Listr(operatorTasks.getDeleteCRsTasks(flags)),
-        })
-        tasks.add({
-          title: 'Delete OLM resources',
-          task: () => new Listr(olmTasks.getDeleteTasks(flags)),
-        })
         tasks.add({
           title: 'Delete operator resources',
-          task: () => new Listr(operatorTasks.getDeleteTasks(flags)),
+          task: () => {
+            const operatorTasks = new OperatorInstaller(flags)
+            return new Listr(operatorTasks.getDeleteTasks())
+          },
         })
+
+        if (ctx[ChectlContext.IS_OPENSHIFT]) {
+          let olmInstaller: Installer
+          if (getProjectName() === DSC_PROJECT_NAME) {
+            olmInstaller = new DevSpacesOLMInstaller(flags)
+          } else {
+            olmInstaller = new CheOLMInstaller(flags)
+          }
+          tasks.add({
+            title: 'Delete OLM resources',
+            task: () => new Listr(olmInstaller.getDeleteTasks()),
+          })
+        }
+
+        const cheTasks = new CheTasks(flags)
         tasks.add({
           title: 'Wait until all pods are deleted',
           task: () => new Listr(cheTasks.getWaitPodsDeletedTasks()),
         })
-        if (flags['delete-namespace'] || flags['delete-all']) {
-          tasks.add(cheTasks.getDeleteNamespaceTasks(flags))
+        if (flags['delete-namespace']) {
+          if (flags.chenamespace === OPENSHIFT_OPERATORS_NAMESPACE) {
+            tasks.add({
+              title: `Delete namespace ${flags.chenamespace}`,
+              task: (_ctx:any, task:any) => task.skip(`${OPENSHIFT_OPERATORS_NAMESPACE} namespace can't be deleted.`),
+            })
+          } else {
+            tasks.add(cheTasks.getDeleteNamespaceTasks(flags))
+          }
         }
 
         return tasks
@@ -140,7 +160,7 @@ export default class Delete extends Command {
 
     if (flags.batch || await this.isDeletionConfirmed(flags)) {
       try {
-        await tasks.run()
+        await tasks.run(ctx)
         cli.log(getCommandSuccessMessage())
       } catch (err: any) {
         this.error(wrapCommandError(err))
