@@ -14,13 +14,13 @@ import { Command, flags } from '@oclif/command'
 import { boolean, string } from '@oclif/parser/lib/flags'
 import { cli } from 'cli-ux'
 import * as Listr from 'listr'
-import { CertManagerTasks } from '../../tasks/component-installers/cert-manager'
+import { CertManagerTasks } from '../../tasks/components/cert-manager'
 import { ChectlContext, OIDCContextKeys, OLM } from '../../api/context'
 import { KubeHelper } from '../../api/kube'
 import { batch, cheDeployVersion, cheNamespace, cheOperatorCRPatchYaml, cheOperatorCRYaml, CHE_OPERATOR_CR_PATCH_YAML_KEY, CHE_OPERATOR_CR_YAML_KEY, CHE_TELEMETRY, DEPLOY_VERSION_KEY, k8sPodDownloadImageTimeout, K8SPODDOWNLOADIMAGETIMEOUT_KEY, k8sPodErrorRecheckTimeout, K8SPODERRORRECHECKTIMEOUT_KEY, k8sPodReadyTimeout, K8SPODREADYTIMEOUT_KEY, k8sPodWaitTimeout, K8SPODWAITTIMEOUT_KEY, listrRenderer, logsDirectory, LOG_DIRECTORY_KEY, skipKubeHealthzCheck as skipK8sHealthCheck } from '../../common-flags'
 import { DEFAULT_ANALYTIC_HOOK_NAME, DEFAULT_CHE_NAMESPACE, DOC_LINK_CONFIGURE_API_SERVER } from '../../constants'
 import { CheTasks } from '../../tasks/che'
-import { DexTasks } from '../../tasks/component-installers/dex'
+import { DexTasks } from '../../tasks/components/dex'
 import {
   createNamespaceTask,
   getPrintHighlightedMessagesTask,
@@ -29,7 +29,8 @@ import {
 import { ApiTasks } from '../../tasks/platforms/api'
 import { PlatformTasks } from '../../tasks/platforms/platform'
 import { askForChectlUpdateIfNeeded, getCommandSuccessMessage, getWarnVersionFlagMsg, notifyCommandCompletedSuccessfully, wrapCommandError } from '../../util'
-import { InstallerTasks } from '../../tasks/installers/installer'
+import { InstallerFactoryTasks } from '../../tasks/installers/installer-factory-tasks'
+import { DevWorkspaceTasks } from '../../tasks/components/devworkspace-operator-installer'
 
 export default class Deploy extends Command {
   static description = 'Deploy Red Hat OpenShift Dev Spaces server'
@@ -177,8 +178,13 @@ export default class Deploy extends Command {
     'skip-kubernetes-health-check': skipK8sHealthCheck,
     'skip-cert-manager': boolean({
       default: false,
-      description: 'Skip installing Cert Manager on the Kubernetes cluster.',
+      description: 'Skip installing Cert Manager (Kubernetes cluster only).',
     }),
+    'skip-devworkspace-operator': boolean({
+      default: false,
+      description: 'Skip installing Dev Workspace Operator (Kubernetes cluster only).',
+    }),
+
     telemetry: CHE_TELEMETRY,
     [DEPLOY_VERSION_KEY]: cheDeployVersion,
   }
@@ -258,9 +264,10 @@ export default class Deploy extends Command {
     const dexTasks = new DexTasks(flags)
     const cheTasks = new CheTasks(flags)
     const platformTasks = new PlatformTasks(flags)
-    const installerTasks = new InstallerTasks()
+    const installerTasks = new InstallerFactoryTasks()
     const apiTasks = new ApiTasks()
     const certManagerTask = new CertManagerTasks(flags)
+    const devWorkspaceTask = new DevWorkspaceTasks(flags)
 
     // Platform Checks
     const platformCheckTasks = new Listr(platformTasks.preflightCheckTasks(flags, this), ctx.listrOptions)
@@ -269,7 +276,7 @@ export default class Deploy extends Command {
     const preInstallTasks = new Listr(undefined, ctx.listrOptions)
     preInstallTasks.add(apiTasks.testApiTasks(flags))
     preInstallTasks.add({
-      title: '👀  Looking for an already existing Red Hat OpenShift Dev Spaces instance',
+      title: 'Looking for an already existing Red Hat OpenShift Dev Spaces instance',
       task: () => new Listr(cheTasks.getCheckIfCheIsInstalledTasks(flags)),
     })
     preInstallTasks.add(ensureOIDCProviderInstalled(flags))
@@ -277,6 +284,7 @@ export default class Deploy extends Command {
     const installTasks = new Listr(undefined, ctx.listrOptions)
     if (!ctx[ChectlContext.IS_OPENSHIFT]) {
       installTasks.add(certManagerTask.getDeployCertManagerTasks())
+      installTasks.add(devWorkspaceTask.getInstallTasks())
     }
     installTasks.add([createNamespaceTask(flags.chenamespace, this.getNamespaceLabels(flags))])
     if (flags.platform === 'minikube') {
@@ -284,19 +292,23 @@ export default class Deploy extends Command {
     }
     installTasks.add({
       title: 'Deploy Red Hat OpenShift Dev Spaces',
-      task: () => new Listr(installerTasks.deployTasks(flags), ctx.listrOptions),
+      task: () => new Listr(installerTasks.getDeployTasks(flags), ctx.listrOptions),
     })
 
     // Post Install Checks
-    const postInstallTasks = new Listr([
+    const postInstallTasks = new Listr(undefined, ctx.listrOptions)
+    postInstallTasks.add(
       {
-        title: '✅  Post installation checklist',
+        title: 'Post installation checklist',
         task: () => new Listr(cheTasks.getWaitCheDeployedTasks()),
       },
-      retrieveCheCaCertificateTask(flags),
-      ...cheTasks.getPreparePostInstallationOutputTasks(flags),
-      getPrintHighlightedMessagesTask(),
-    ], ctx.listrOptions)
+    )
+    if (flags.platform === 'minikube') {
+      postInstallTasks.add(devWorkspaceTask.createOrUpdateDevWorkspaceOperatorConfigTasks())
+    }
+    postInstallTasks.add(retrieveCheCaCertificateTask(flags))
+    postInstallTasks.add(cheTasks.getPreparePostInstallationOutputTasks(flags))
+    postInstallTasks.add(getPrintHighlightedMessagesTask())
 
     const logsTasks = new Listr([{
       title: 'Following Red Hat OpenShift Dev Spaces logs',
