@@ -10,15 +10,15 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import {Command, flags} from '@oclif/command'
-import {string} from '@oclif/parser/lib/flags'
-import {cli} from 'cli-ux'
+import { Command, flags } from '@oclif/command'
+import { boolean, string } from '@oclif/parser/lib/flags'
+import { cli } from 'cli-ux'
 import * as Listr from 'listr'
 import * as semver from 'semver'
 
-import {CheHelper} from '../../api/che'
-import {ChectlContext} from '../../api/context'
-import {KubeHelper} from '../../api/kube'
+import { CheHelper } from '../../api/che'
+import { ChectlContext } from '../../api/context'
+import { KubeHelper } from '../../api/kube'
 import {
   assumeYes,
   batch,
@@ -37,9 +37,9 @@ import {
   OPERATOR_IMAGE_NAME,
   OPERATOR_IMAGE_NEXT_TAG,
 } from '../../constants'
-import {getPrintHighlightedMessagesTask} from '../../tasks/installers/common-tasks'
-import {InstallerTasks} from '../../tasks/installers/installer'
-import {ApiTasks} from '../../tasks/platforms/api'
+import { getPrintHighlightedMessagesTask } from '../../tasks/installers/common-tasks'
+import { InstallerFactoryTasks } from '../../tasks/installers/installer-factory-tasks'
+import { ApiTasks } from '../../tasks/platforms/api'
 import {
   askForChectlUpdateIfNeeded,
   findWorkingNamespace,
@@ -50,6 +50,7 @@ import {
   notifyCommandCompletedSuccessfully,
   wrapCommandError,
 } from '../../util'
+import { DevWorkspaceTasks } from '../../tasks/components/devworkspace-operator-installer'
 
 export default class Update extends Command {
   static description = 'Update Red Hat OpenShift Dev Spaces server.'
@@ -93,6 +94,10 @@ export default class Update extends Command {
     [CHE_OPERATOR_CR_PATCH_YAML_KEY]: cheOperatorCRPatchYaml,
     telemetry: CHE_TELEMETRY,
     [DEPLOY_VERSION_KEY]: cheDeployVersion,
+    'skip-devworkspace-operator': boolean({
+      default: false,
+      description: 'Skip updating Dev Workspace Operator (Kubernetes cluster only).',
+    }),
   }
 
   async run() {
@@ -120,7 +125,7 @@ export default class Update extends Command {
 
     await this.config.runHook(DEFAULT_ANALYTIC_HOOK_NAME, { command: Update.id, flags })
 
-    const installerTasks = new InstallerTasks()
+    const installerTasks = new InstallerFactoryTasks()
 
     // pre update tasks
     const apiTasks = new ApiTasks()
@@ -128,14 +133,18 @@ export default class Update extends Command {
     preUpdateTasks.add(apiTasks.testApiTasks(flags))
     preUpdateTasks.add({
       title: 'Preflight check',
-      task: () => new Listr(installerTasks.preUpdateTasks(flags), ctx.listrOptions),
+      task: () => new Listr(installerTasks.getPreUpdateTasks(flags), ctx.listrOptions),
     })
 
     // update tasks
     const updateTasks = new Listr([], ctx.listrOptions)
+    if (!ctx[ChectlContext.IS_OPENSHIFT]) {
+      const devWorkspaceTask = new DevWorkspaceTasks(flags)
+      updateTasks.add(devWorkspaceTask.getUpdateTasks())
+    }
     updateTasks.add({
       title: 'Update Red Hat OpenShift Dev Spaces',
-      task: () => new Listr(installerTasks.updateTasks(flags), ctx.listrOptions),
+      task: () => new Listr(installerTasks.getUpdateTasks(flags), ctx.listrOptions),
     })
 
     // post update tasks
@@ -287,9 +296,9 @@ export default class Update extends Command {
    */
   private async setDomainFlag(flags: any): Promise<void> {
     const kubeHelper = new KubeHelper(flags)
-    const cheCluster = await kubeHelper.getCheClusterV1(flags.chenamespace)
-    if (cheCluster?.spec?.k8s?.ingressDomain) {
-      flags.domain = cheCluster.spec.k8s.ingressDomain
+    const cheCluster = await kubeHelper.getCheClusterV2(flags.chenamespace)
+    if (cheCluster?.spec?.networking?.domain) {
+      flags.domain = cheCluster.spec.networking.domain
     }
   }
 
