@@ -28,7 +28,6 @@ import { KubeHelper } from './api/kube'
 import { VersionHelper } from './api/version'
 import {
   CHE_CLUSTER_API_GROUP,
-  CHE_CLUSTER_API_VERSION_V1,
   CHE_CLUSTER_API_VERSION_V2,
   CHE_TLS_SECRET_NAME,
 } from './constants'
@@ -209,7 +208,8 @@ export function wrapCommandError(error: Error): Error {
 }
 
 export function newError(message: string, cause: Error): Error {
-  const error = new Error(message)
+  const error = new Error(message) as any
+  error.cause = cause
   error.stack += `\nCause: ${cause.stack}`
   return error
 }
@@ -376,7 +376,7 @@ export function confirmYN(): Promise<boolean> {
   })
 }
 
-export function getTlsSecretName(ctx: any): string  {
+export function getTlsSecretName(ctx: any): string {
   const crPatch = ctx[ChectlContext.CR_PATCH]
 
   if (crPatch?.spec?.k8s?.tlsSecretName !== undefined) {
@@ -404,10 +404,6 @@ export function getWarnVersionFlagMsg(_flags: any): string {
 2. Use dsc of the specific version to deploy or to upgrade Red Hat OpenShift Dev Spaces`
 }
 
-export function isCheClusterAPIV1(checluster: any): boolean {
-  return checluster.apiVersion === `${CHE_CLUSTER_API_GROUP}/${CHE_CLUSTER_API_VERSION_V1}`
-}
-
 export function isCheClusterAPIV2(checluster: any): boolean {
   return checluster.apiVersion === `${CHE_CLUSTER_API_GROUP}/${CHE_CLUSTER_API_VERSION_V2}`
 }
